@@ -6,6 +6,8 @@
 """
 from .fourierwavelet import fourier, wavelets_dwt, wavelets_cwt
 
-__author__ = 'Artem Radaykin'
+__author__ = 'Марк Козлов, Вячеслав Есаков, Артём Радайкин, Александр Савостьянов, Лев Памбухчян'
 
-__version__ = "0.0.1"
\ No newline at end of file
+__all__ = ['fourier', 'wavelets_dwt', 'wavelets_cwt']
+
+__version__ = "0.0.6"
\ No newline at end of file
